@@ -32,7 +32,7 @@ import tempfile
 
 from sqlalchemy import orm
 
-from rattail.util import load_object, pretty_quantity
+from rattail.util import load_object, pretty_quantity, progress_loop
 from rattail.files import temp_path
 from rattail.mail import send_email
 
@@ -119,6 +119,10 @@ class AppHandler(object):
             self.auth_handler = factory(self.config, **kwargs)
         return self.auth_handler
 
+    def get_batch_handler(self, key, **kwargs):
+        from rattail.batch import get_batch_handler
+        return get_batch_handler(self.config, key, **kwargs)
+
     def get_board_handler(self, **kwargs):
         if not hasattr(self, 'board_handler'):
             from rattail.board import get_board_handler
@@ -190,6 +194,9 @@ class AppHandler(object):
             self.report_handler = get_report_handler(self.config, **kwargs)
         return self.report_handler
 
+    def progress_loop(self, *args, **kwargs):
+        return progress_loop(*args, **kwargs)
+
     def get_session(self, obj):
         """
         Returns the SQLAlchemy session with which the given object is
@@ -328,6 +335,9 @@ class GenericHandler(object):
         self.model = self.config.get_model()
         self.app = self.config.get_app()
 
+    def progress_loop(self, *args, **kwargs):
+        return self.app.progress_loop(*args, **kwargs)
+
     def get_session(self, obj):
         """
         Convenience wrapper around :meth:`AppHandler.get_session()`.
