@@ -580,6 +580,10 @@ class RattailConfig(object):
         """
         Returns the title string to be used when displaying product key field,
         e.g. "UPC" or "Part No." etc.
+
+        :param key: The product key for which to return a label.  This
+           is optional; if not specified then :meth:`product_key()`
+           will be called to determine the key.
         """
         title = self.get('rattail', 'product.key_title')
         if title:
