@@ -368,6 +368,11 @@ class FromRattailToRattailBase(NewDataSyncImportConsumer):
     def get_importers(self):
         importers = super(FromRattailToRattailBase, self).get_importers()
 
+        # add the GlobalRole importer, in place of Role, unless latter
+        # is already present.
+        if 'Role' not in importers:
+            importers['Role'] = self.handler.get_importer('GlobalRole')
+
         # maybe add importer to handle product price reference changes
         if self.get_handle_price_xref() and 'ProductPriceAssociation' not in importers:
             importers['ProductPriceAssociation'] = self.handler.get_importer('ProductPriceAssociation')
