@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,11 @@
 Data Models for Email Bouncer Daemon
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import datetime
 
+import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -35,6 +36,62 @@ from rattail.db.model import Base, uuid_column
 from rattail.db.model import User
 
 
+class EmailAttempt(Base):
+    """
+    Represents an attempt to send an email.  Ideally the generated message body
+    is persisted on disk, in addition to these details.
+    """
+    __tablename__ = 'email_attempt'
+
+    uuid = uuid_column()
+
+    key = sa.Column(sa.String(length=254), nullable=False, doc="""
+    Config key for the email being sent.
+    """)
+
+    sender = sa.Column(sa.Text(), nullable=False, doc="""
+    Value for the From: email header.
+    """)
+
+    to = sa.Column(sa.Text(), nullable=False, doc="""
+    Value for the To: email header.
+    """)
+
+    cc = sa.Column(sa.Text(), nullable=True, doc="""
+    Value for the Cc: email header.
+    """)
+
+    bcc = sa.Column(sa.Text(), nullable=True, doc="""
+    Value for the Bcc: email header.
+    """)
+
+    subject = sa.Column(sa.String(length=254), nullable=False, default='', doc="""
+    Value for the Subject: email header.
+    """)
+
+    sent = sa.Column(sa.DateTime(), nullable=False, doc="""
+    Date and time when email send attempt was first made.
+    """)
+
+    status_code = sa.Column(sa.Integer(), nullable=False, doc="""
+    Status code for the email.
+    """)
+
+    status_text = sa.Column(sa.Text(), nullable=True, doc="""
+    Status text for the email, if applicable.
+    """)
+
+    def __str__(self):
+        if six.PY2:
+            return self.subject.encode('utf8')
+        return self.subject
+
+    if six.PY2:
+        def __unicode__(self):
+            return self.subject
+
+
+@six.python_2_unicode_compatible
 class EmailBounce(Base):
     """
     Represents an email bounce notification message.  This table is populated
@@ -79,7 +136,7 @@ class EmailBounce(Base):
     Reference to the :class:`rattail.db.model.User` who processed the bounce.
     """)
 
-    def __unicode__(self):
+    def __str__(self):
         if self.intended_recipient_address:
-            return unicode(self.intended_recipient_address)
-        return unicode(self.bounce_recipient_address)
+            return str(self.intended_recipient_address)
+        return str(self.bounce_recipient_address)
