@@ -100,6 +100,8 @@ class FromRattailToRattailBase(object):
         importers['PersonPhoneNumber'] = PersonPhoneNumberImporter
         importers['PersonMailingAddress'] = PersonMailingAddressImporter
         importers['MergePeopleRequest'] = MergePeopleRequestImporter
+        importers['Role'] = RoleImporter
+        importers['GlobalRole'] = GlobalRoleImporter
         importers['User'] = UserImporter
         importers['AdminUser'] = AdminUserImporter
         importers['GlobalUser'] = GlobalUserImporter
@@ -151,6 +153,8 @@ class FromRattailToRattailBase(object):
         keys = self.get_importer_keys()
 
         avoid_by_default = [
+            'Role',
+            'GlobalRole',
             'GlobalPerson',
             'AdminUser',
             'GlobalUser',
@@ -260,6 +264,131 @@ class PersonMailingAddressImporter(FromRattail, model.PersonMailingAddressImport
 class MergePeopleRequestImporter(FromRattail, model.MergePeopleRequestImporter):
     pass
 
+class RoleImporter(FromRattail, model.RoleImporter):
+    pass
+
+
+class GlobalRoleImporter(RoleImporter):
+    """
+    Role importer which only will handle roles which have the
+    :attr:`~rattail.db.model.users.Role.sync_me` flag set.  (So it
+    syncs those roles but avoids others.)
+    """
+
+    @property
+    def supported_fields(self):
+        fields = list(super(GlobalRoleImporter, self).supported_fields)
+        fields.extend([
+            'permissions',
+            'users',
+        ])
+        return fields
+
+    # nb. we must override both cache_query() and query() b/c they use
+    # different sessions!
+
+    def cache_query(self):
+        """
+        Return the query to be used when caching "local" data.
+        """
+        query = super(GlobalRoleImporter, self).cache_query()
+        model = self.model
+
+        # only want roles which are *meant* to be synced
+        query = query.filter(model.Role.sync_me == True)
+
+        return query
+
+    def query(self):
+        query = super(GlobalRoleImporter, self).query()
+        model = self.model
+
+        # only want roles which are *meant* to be synced
+        query = query.filter(model.Role.sync_me == True)
+
+        return query
+
+    # nb. we do not need to override normalize_host_object() b/c it
+    # just calls normalize_local_object() by default
+
+    def normalize_local_object(self, role):
+
+        # only want roles which are *meant* to be synced
+        if not role.sync_me:
+            return
+
+        data = super(GlobalRoleImporter, self).normalize_local_object(role)
+        if data:
+
+            # users
+            if 'users' in self.fields:
+                data['users'] = sorted([user.uuid for user in role.users])
+
+            # permissions
+            if 'permissions' in self.fields:
+                auth = self.app.get_auth_handler()
+                perms = auth.cache_permissions(self.session, role,
+                                               include_guest=False)
+                data['permissions'] = sorted(perms)
+
+            return data
+
+    def update_object(self, role, host_data, local_data=None, **kwargs):
+        role = super(GlobalRoleImporter, self).update_object(role, host_data,
+                                                             local_data=local_data,
+                                                             **kwargs)
+        model = self.model
+
+        # users
+        if 'users' in self.fields:
+            new_users = host_data['users']
+            old_users = local_data['users'] if local_data else []
+            changed = False
+
+            # add some users
+            for new_user in new_users:
+                if new_user not in old_users:
+                    user = self.session.query(model.User).get(new_user)
+                    if user:
+                        user.roles.append(role)
+                        changed = True
+
+            # remove some users
+            for old_user in old_users:
+                if old_user not in new_users:
+                    user = self.session.query(model.User).get(old_user)
+                    if user:
+                        user.roles.remove(role)
+                        changed = True
+
+            if changed:
+                # also record a change to the role, for datasync.
+                # this is done "just in case" the role is to be
+                # synced to all nodes
+                if self.session.rattail_record_changes:
+                    self.session.add(model.Change(class_name='Role',
+                                                  instance_uuid=role.uuid,
+                                                  deleted=False))
+
+        # permissions
+        if 'permissions' in self.fields:
+            auth = self.app.get_auth_handler()
+            new_perms = host_data['permissions']
+            old_perms = local_data['permissions'] if local_data else []
+
+            # grant permissions
+            for new_perm in new_perms:
+                if new_perm not in old_perms:
+                    auth.grant_permission(role, new_perm)
+
+            # revoke permissions
+            for old_perm in old_perms:
+                if old_perm not in new_perms:
+                    auth.revoke_permission(role, old_perm)
+
+        return role
+
+
 class UserImporter(FromRattail, model.UserImporter):
     pass
 
