@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -30,4 +30,4 @@ for more information.
 
 from rattail.sil.columns import *
 from .batches import consume_batch_id
-from rattail.sil.writer import *
+from rattail.sil.writer import Writer
