@@ -1,11 +1,12 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import logging
 from unittest import TestCase
-from cStringIO import StringIO
+from six import StringIO
 
+import six
 from mock import patch
 
 from rattail import logging as rattail_logging
@@ -33,6 +34,9 @@ class TestLogging(TestCase):
         log = rattail_logging.RattailAdapter(log)
         self.assertEqual(string.getvalue(), "")
         log.debug("some random thing")
-        self.assertEqual(string.getvalue(), "testing.rattailproject.org 127.0.0.1 [u'just', u'testing'] joeschmoe 420 DEBUG some random thing\n")
+        if six.PY3:
+            self.assertEqual(string.getvalue(), "testing.rattailproject.org 127.0.0.1 ['just', 'testing'] joeschmoe 420 DEBUG some random thing\n")
+        else:
+            self.assertEqual(string.getvalue(), "testing.rattailproject.org 127.0.0.1 [u'just', u'testing'] joeschmoe 420 DEBUG some random thing\n")
         handler.close()
         string.close()
